@@ -1,10 +1,12 @@
+//! This file exists for testing purposes.
+
 use std::io;
 
 fn main() {
     let stdout = io::stdout();
     let mut terminal = tanmatsu::Terminal::new(stdout.lock()).unwrap();
 
-    // This file exists for testing purposes.
+    terminal.initialize(None, false);
 
     terminal.flush();
 
